
<?php

if(!isset($estatebud_api)) return;

/**
 * Provide a form for creating and editing shortcodes in a modal
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       http://estatebud.com
 * @since      1.0.0
 *
 * @package    Estatebud
 * @subpackage Estatebud/admin/partials
 */

/**
 *@param int $property_id
 * @param int $area
 * @param string $category
 * @param string $type
 * @param int $city
 * @param date $date_from
 * @param date $date_to
 * @param bool $public
 * @param bool $featured
 * @param string $title_deed = yes, yes_share_of_land, final_approval, no
 * @param integer $bedrooms_min
 * @param integer $bedrooms_max
 * @param integer $bathrooms_min
 * @param integer $bathrooms_max
 * @param integer $covered_sqm_min
 * @param integer $covered_sqm_max
 * @param integer $price_min
 * @param integer $price_max
 * @param string $status = resale, key_ready, under_construction, off_plan
 * @param bool $sea_view
 * @param bool $sea_front
 * @param bool $swimming_pool
 * @param bool $walking_distance_to_beach
 * @param integer $rent_min
 * @param integer $rent_max
 * @param string $sort = availability, property_id (default), price, rent
 * @param string $sort_type = DESC, ASC
 * @param integer $offset
 * @param integer $limit
 **/

 function estatebud_length_squared($system){
     switch($system){
         case "metric": return "m²";
         case "imperial": return "ft²";
     }
     return "m²";
 }

?>

<div id="estatebud-shortcode-form" style="display: none">
    <form method="post" onsubmit="return estatebud.new_shortcode(this);" id="estatebud-shortcode-form-element">
    <?php wp_nonce_field( "estatebud_save_shortcode", "shortcode_security"); ?>
    <input type="hidden" id="action_field" name="action" value="estatebud_save_shortcode">
    <input type="hidden" name='old_key' value=''>
    <input type="hidden" name='create' value=''>
    <div class="container bootstrap-container">
        <div class="row estatebud-notice-row"></div>
        <div class="row">
            <div class="col-md-12">
                <div class="form-field">
                    <label><?php echo __("Shortcode Key", "estatebud");?></label>
                    <div style="flex: 1">
                        <input type="text" class="form-control" name="shortcode_key" required minlength="3"><br>
                        <p class="description"><?php _e("This will be the code you will use to insert a shortcode to any page/post you desire. Will start with `estatebud_`", "estatebud");?></p>
                    </div>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-md-12">
                <div class="form-field">
                    <label><?php _e("Shortcode Description", "estatebud");?></label>
                    <div style="flex: 1">
                        <textarea name="shortcode_description" rows="3" class="form-control"></textarea><br>
                        <p class="description"><?php _e("You can write a short description here to distinguish between your shortcodes.", "estatebud");?></p>
                    </div>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-md-12">
                <div class="form-field">
                    <label><?php _e("Property ID(s)", "estatebud");?></label>
                    <div style="flex: 1">
                        <input type="text" class="form-control" name="property_id">
                        <p class="description"><?php _e("You can add more than one property ID by separating the values with a comma (,).", "estatebud");?></p>
                    </div>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-md-12">
                <div class="form-field">
                    <label><?php _e("Complex Name", "estatebud");?></label>
                    <div style="flex: 1">
                        <input type="text" class="form-control" name="complex">
                    </div>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-md-12">
                <div class="form-field">
                    <label><?php _e("Property Category", "estatebud");?></label>
                    <select class="form-control" name="category[]" multiple>
                        <?php
                            $categories = $estatebud_api->get_property_categories();
                            $groups = get_object_vars($categories);
                            foreach($groups as $key => $group){
                                echo "<optgroup label='" . $key . "'>";
                                $category_list = get_object_vars($group);
                                foreach($category_list as $key2 => $category){
                                    echo "<option value='". esc_attr($key2) . "' selected>" . $key . " - " . $category . "</option>";
                                }
                                echo "</optgroup>";
                            }
                        ?>
                    </select>
                </div>
            </div>
            <div class="col-md-12">
                <div class="form-field">
                    <label><?php _e("Property Type", "estatebud");?></label>
                    <select class="form-control" name="type[]" multiple>
                        <?php
                            $types = $estatebud_api->get_property_types();
                            $type_list = get_object_vars($types);
                            foreach($type_list as $key => $type){
                                echo "<option value='".esc_attr($key)."'>" . $type . "</option>";
                            }
                        ?>
                    </select>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-md-12">
                <div class="form-field">
                    <label><?php _e("Location", "estatebud");?></label>
                    <select class="form-control" multiple name="area[]">
                    <?php $areas = $estatebud_api->get_property_areas();
                        foreach($areas as $country){
                            $prefix = $country["name"];
                            echo "<option value='".esc_attr($country["id"])."'>" . $prefix . "</option>";
                            if(isset($country["areas"]) && is_array($country["areas"]) && count($country["areas"]) > 0){
                                foreach($country["areas"] as $state){
                                    $prefix2 = $prefix . " &raquo; " . $state["name"];
                                    echo "<option value='".esc_attr($state["id"])."'>" . $prefix2 . "</option>";
                                    if(isset($state["areas"]) && is_array($state["areas"]) && count($state["areas"]) > 0){
                                        foreach($state["areas"] as $city){
                                            $prefix3 = $prefix2 . " &raquo; " . $city["name"];
                                            echo "<option value='".esc_attr($city["id"])."'>" . $prefix3 . "</option>";
                                            if(isset($city["areas"]) && is_array($city["areas"]) && count($city["areas"]) > 0){
                                                foreach($city["areas"] as $nhood){
                                                    $prefix4 = $prefix3 . " &raquo; " . $nhood["name"];
                                                    echo "<option value='".esc_attr($nhood["id"])."'>" . $prefix4 . "</option>";
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    ?>
                    </select>
                </div>
            </div>
            <div class="col-md-12">
                <div class="form-field">
                    <label><?php _e("Property Labels", "estatebud");?></label>
                    <select class="form-control" name="label[]" multiple>
                        <?php
                            $labels = $estatebud_api->get_property_labels();
                            foreach($labels as $label){
                                echo "<option value='". $label->id . "' selected>" . $label->name . "</option>";
                            }
                        ?>
                    </select>
                </div>
            </div>
            <div class="col-md-12">
                <div class="form-field">
                    <label><?php _e("Status", "estatebud");?></label>
                    <select class="form-control" name="status[]" multiple>
                        <?php
                            $statuses = $estatebud_api->get_property_statuses();
                            foreach($statuses as $key => $status){
                                echo "<option value='". $key . "' selected>" . $status . "</option>";
                            }
                        ?>
                    </select>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-md-6">
                <div class="form-field">
                    <label><?php _e("Facilities", "estatebud");?></label>
                    <div class="input-group">
                        <label><input type="checkbox" name="sea_view" value="1"> <?php _e("Sea View", "estatebud");?></label><br>
                        <label><input type="checkbox" name="sea_front" value="1"> <?php _e("Sea Front", "estatebud");?></label><br>
                        <label><input type="checkbox" name="swimming_pool" value="1"> <?php _e("Swimming Pool", "estatebud");?></label><br>
                        <label><input type="checkbox" name="walking_distance_to_beach" value="1"> <?php _e("Walking Distance to Beach", "estatebud");?></label><br>
                    </div>
                </div>
            </div>
            <div class="col-md-6">
                <div class="form-field">
                    <label><?php _e("Title Deed", "estatebud");?></label>
                    <div class="input-group">
                        <label><input type="checkbox" name="title_deed" value="1"> <?php _e("Yes", "estatebud");?></label><br>
                    </div>
                </div>
                <div class="form-field">
                    <label><?php _e("Other", "estatebud");?></label>
                    <div class="input-group">
                        <label><input type="checkbox" name="featured" value="1"> <?php _e("Featured", "estatebud");?></label><br>
                    </div>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-md-6">
                <div class="form-field">
                    <label><?php _e("Available From", "estatebud");?></label>
                    <input type="date" class="form-control" name="date_from">
                </div>
            </div>
            <div class="col-md-6">
                <div class="form-field">
                    <label><?php _e("Available Until", "estatebud");?></label>
                    <input type="date" class="form-control" name="date_to">
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-md-6">
                <div class="form-field">
                    <label><?php _e("Price Min", "estatebud");?></label>
                    <input type="number" class="form-control" name="price_min" value="0" step="1" min="0" max="999999999">
                </div>
            </div>
            <div class="col-md-6">
                <div class="form-field">
                    <label><?php _e("Price Max", "estatebud");?></label>
                    <input type="number" class="form-control" name="price_max" value="0" step="1" min="0" max="999999999">
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-md-6">
                <div class="form-field">
                    <label><?php _e("Rent Min", "estatebud");?></label>
                    <input type="number" class="form-control" name="rent_min" value="0" step="1" min="0" max="999999999">
                </div>
            </div>
            <div class="col-md-6">
                <div class="form-field">
                    <label><?php _e("Rent Max", "estatebud");?></label>
                    <input type="number" class="form-control" name="rent_max" value="0" step="1" min="0" max="999999999">
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-md-6">
                <div class="form-field">
                    <label><?php _e("Bedrooms Min", "estatebud");?></label>
                    <input type="number" class="form-control" name="bedrooms_min" value="0" step="1" min="0" max="999">
                </div>
            </div>
            <div class="col-md-6">
                <div class="form-field">
                    <label><?php _e("Bedrooms Max", "estatebud");?></label>
                    <input type="number" class="form-control" name="bedrooms_max" value="0" step="1" min="0" max="999">
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-md-6">
                <div class="form-field">
                    <label><?php _e("Bathrooms Min", "estatebud");?></label>
                    <input type="number" class="form-control" name="bathrooms_min" value="0" step="1" min="0" max="999">
                </div>
            </div>
            <div class="col-md-6">
                <div class="form-field">
                    <label><?php _e("Bathrooms Max", "estatebud");?></label>
                    <input type="number" class="form-control" name="bathrooms_max" value="0" step="1" min="0" max="999">
                </div>
            </div>
        </div>
        <?php if($estatebud_api->auth_info->measurements == "metric") : ?>
        <div class="row">
            <div class="col-md-6">
                <div class="form-field">
                    <label><?php _e("Covered " . estatebud_length_squared($estatebud_api->auth_info->measurements) . " Min", "estatebud");?></label>
                    <input type="number" class="form-control" name="covered_m2_min" value="0" step="1" min="0" max="999999">
                </div>
            </div>
            <div class="col-md-6">
                <div class="form-field">
                    <label><?php _e("Covered " . estatebud_length_squared($estatebud_api->auth_info->measurements) . " Max", "estatebud");?></label>
                    <input type="number" class="form-control" name="covered_m2_max" value="0" step="1" min="0" max="999999">
                </div>
            </div>
        </div>
        <?php else: ?>
        <div class="row">
            <div class="col-md-6">
                <div class="form-field">
                    <label><?php _e("Covered " . estatebud_length_squared($estatebud_api->auth_info->measurements) . " Min", "estatebud");?></label>
                    <input type="number" class="form-control" name="covered_ft2_min" value="0" step="1" min="0" max="999999">
                </div>
            </div>
            <div class="col-md-6">
                <div class="form-field">
                    <label><?php _e("Covered " . estatebud_length_squared($estatebud_api->auth_info->measurements) . " Max", "estatebud");?></label>
                    <input type="number" class="form-control" name="covered_ft2_max" value="0" step="1" min="0" max="999999">
                </div>
            </div>
        </div>
        <?php endif; ?>
        <div class="row">
            <div class="col-md-6">
                <div class="form-field">
                    <label><?php _e("Records per Page", "estatebud");?></label>
                    <input type="number" class="form-control" name="limit" value="12" step="1" min="0" max="999">
                </div>
            </div>
            <div class="col-md-6">
                <div class="form-field">
                    <label><?php _e("Sort Records By", "estatebud");?></label>
                    <select name="sort" class="form-control">
                        <option value="availability"><?php _e("Availability", "estatebud");?></option>
                        <option value="property_id" selected><?php _e("Property ID", "estatebud");?></option>
                        <option value="price"><?php _e("Price", "estatebud");?></option>
                        <option value="rent"><?php _e("Rent", "estatebud");?></option>
                    </select>
                </div>
            </div>
            <div class="col-md-6">
                <div class="form-field">
                    <label><?php _e("Sort Direction", "estatebud");?></label>
                    <select name="sort_type" class="form-control">
                        <option value="ASC"><?php _e("Ascending", "estatebud");?></option>
                        <option value="DESC" selected><?php _e("Descending", "estatebud");?></option>
                    </select>
                </div>
            </div>
        </div>
        <?php submit_button(__("Add New Shortcode", "estatebud"));?>
    </div>
    </form>
</div>