<?php

class Estatebud_Widget extends WP_Widget
{

    function __construct()
    {
        parent::__construct(
            'estatebud-widget',  // Base ID
            __("'Estatebud Widget'", "estatebud")   // Name
        );
        add_action('widgets_init', function () {
            register_widget('Estatebud_Widget');
        });
    }

    public $args = array(
        'before_title' => '<h4 class="widgettitle">',
        'after_title' => '</h4>',
        'before_widget' => '<div class="widget-wrap">',
        'after_widget' => '</div></div>'
    );

    public function widget($args, $instance)
    {
        echo $args['before_widget'];
        if (!empty($instance['title'])) {
            echo $args['before_title'] . apply_filters('widget_title', $instance['title']) . $args['after_title'];
        }
        echo do_shortcode("[estatebud_" . $instance["shortcode"] . " is_widget='true' limit='" . $instance["limit"] . "' layout='".$instance["layout"]."']");
        echo $args['after_widget'];
    }

    public function form($instance)
    {
        $title = !empty($instance['title']) ? $instance['title'] : esc_html__('', 'estatebud');
        $limit = !empty($instance['limit']) ? intval($instance['limit']) : 1;
        $shortcode = !empty($instance['shortcode']) ? $instance['shortcode'] : esc_html__('', 'estatebud');
        $layout = !empty($instance['layout'] ) ? $instance['layout'] : "vertical";
        ?>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_attr_e('Title:', 'estatebud'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($title); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('limit')); ?>"><?php esc_attr_e('Property Count:', 'estatebud'); ?></label>
            <select class="widefat" id="<?php echo esc_attr($this->get_field_id('limit')); ?>" name="<?php echo esc_attr($this->get_field_name('limit')); ?>" >
                <?php for ($i = 1; $i < 20; $i++) {
                    echo "<option value='$i'" . (($limit == $i) ? " selected" : "") . ">$i</option>";
                } ?>
            </select>
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('shortcode')); ?>"><?php esc_attr_e('Shortcode:', 'estatebud'); ?></label>
            <select class="widefat" id="<?php echo esc_attr($this->get_field_id('shortcode')); ?>" name="<?php echo esc_attr($this->get_field_name('shortcode')); ?>" >
                <?php
                $shortcodes = get_option("estatebud_shortcode_settings", []);
                foreach (array_keys($shortcodes) as $shortcode_tag) {
                    echo "<option value='".esc_attr($shortcode_tag)."'" . (($shortcode_tag == $shortcode) ? " selected" : "") . ">[estatebud_$shortcode_tag]</option>";
                } ?>
            </select>
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('layout')); ?>"><?php esc_attr_e('Layout:', 'estatebud'); ?></label>
            <select class="widefat" id="<?php echo esc_attr($this->get_field_id('layout')); ?>" name="<?php echo esc_attr($this->get_field_name('layout')); ?>" >
                <?php
                foreach (["horizontal","vertical"] as $xlayout) {
                    echo "<option value='".esc_attr($xlayout)."'" . (($layout == $xlayout) ? " selected" : "") . ">". ucfirst($xlayout) . "</option>";
                } ?>
            </select>
        </p>
        <?php

    }

    public function update($new_instance, $old_instance)
    {
        $instance = array();
        $instance['title'] = (!empty($new_instance['title'])) ? strip_tags($new_instance['title']) : '';
        $instance['limit'] = (!empty($new_instance['limit'])) ? intval($new_instance['limit']) : 0;
        $instance['layout'] = (!empty($new_instance['layout']) && in_array($new_instance["layout"], ["vertical", "horizontal"])) ? $new_instance['layout'] : 'vertical';
        $instance['shortcode'] = (!empty($new_instance['shortcode'])) ? sanitize_text_field($new_instance['shortcode']) : 0;
        return $instance;
    }

}
$estatebud_widget = new Estatebud_Widget();