(function ($) {
    $(document).ready(function () {
        window.estatebudStylizeFilterForm = function (container) {
            if (container.length > 0) {
                container.find("select:not([multiple])").select2({
                    theme: "estatebud",
                    minimumResultsForSearch: -1
                });
                container.find("select[multiple]").select2({
                    closeOnSelect: false,
                    theme: "estatebud",
                    minimumResultsForSearch: -1,
                    templateResult: function (data) {
                        if (!data.element) return data.text;
                        var $element = $(data.element);
                        var $wrapper = $('<span></span>');
                        $wrapper.addClass($element[0].className);
                        $wrapper.text(data.text);
                        return $wrapper;
                    }
                });
                container.find(".estatebud-filter-form-more").css("display", "none");

                container.find("select[multiple]").on('change', function () {
                    if ($(this).val() !== null) {
                        var selected = $(this).val().length;
                        var total = $(this).find('option').length;
                        $(this).parent().find('.select2-selection ul').html(estatebudL10n.select2_format.replace('{count}', selected).replace('{total}', total));
                    } else {
                        $(this).parent().find('.select2-selection ul').html(estatebudL10n.select2_empty);
                    }
                }).trigger('change');

                container.find("select[multiple]").each(function () {
                    $(this).siblings('span.select2').find('.select2-selection').append('<span class="select2-selection__arrow" role="presentation"><b role="presentation"></b></span>');
                });

                container.find("select[multiple]").on('select2:select', function (e) {
                    var $this = $(e.params.data.element);
                    if ($this.hasClass("estatebud_select2_l1")) {
                        $this.nextUntil(".estatebud_select2_l1").prop("selected", true);
                    } else if ($this.hasClass("estatebud_select2_l2")) {
                        $this.nextUntil(".estatebud_select2_l1, .estatebud_select2_l2").prop("selected", true);
                    } else if ($this.hasClass("estatebud_select2_l3")) {
                        $this.nextUntil(".estatebud_select2_l1, .estatebud_select2_l2, .estatebud_select2_l3").prop("selected", true);
                    }
                    $(this).select2("close").select2("open").trigger("change");
                });

                container.find("select[multiple]").on("select2:unselect", function (e) {
                    var $this = $(e.params.data.element);
                    if ($this.hasClass("estatebud_select2_l1")) {
                        $this.nextUntil(".estatebud_select2_l1").prop("selected", false);
                    } else if ($this.hasClass("estatebud_select2_l2")) {
                        $this.nextUntil(".estatebud_select2_l1, .estatebud_select2_l2").prop("selected", false);
                    } else if ($this.hasClass("estatebud_select2_l3")) {
                        $this.nextUntil(".estatebud_select2_l1, .estatebud_select2_l2, .estatebud_select2_l3").prop("selected", false);
                    }
                    $(this).select2("close").select2("open").trigger("change");
                });
            }
        };

        if (estatebud.is_listing) {
            var container = $(".estatebud-filter-form");

            if (container.length > 0) {
                estatebudStylizeFilterForm(container);

                $("#estatebud_form_toggle").on("click", function () {
                    var that = $(this);
                    container.find(".estatebud-filter-form-more").slideToggle("fast", "swing", function () {
                        if ($(this).is(":visible")) {
                            that.find("span").text(estatebudL10n.show_less);
                            that.addClass("show_less");
                        } else {
                            that.find("span").text(estatebudL10n.show_more);
                            that.removeClass("show_less");
                        }
                    });
                });

                var ajaxRequest = null;
                var rolling_back = true;
                var scroll_to_top = false;

                var estatebud_refresh_property_list = function () {
                    if (ajaxRequest) ajaxRequest.abort();

                    if (scroll_to_top) {
                        $("html, body").animate({
                            scrollTop: $(".estatebud").offset().top
                        }, 600);
                        scroll_to_top = false;
                    }

                    ajaxRequest = $.ajax({
                        url: estatebud.ajaxurl,
                        method: "GET",
                        data: estatebud_form_serialize(false),
                        headers: {
                            "Estatebud-Shortcode": estatebud.shortcode.current.shortcode_key
                        },
                        success: function (data) {
                            $(".estatebud-listing-container").html(data);
                            estatebud_update_document_hash(estatebud_form_serialize(true));
                            rolling_back = false;
                        }
                    });
                };

                var estatebud_form_serialize = function (remove) {
                    var values = container.find("form").serializeArray();
                    if (remove) {
                        values = estatebud_serialize_arrays(values);
                        for (var key in values) {
                            var value1 = estatebud.shortcode.current[estatebud_fix_key(key)];
                            var value2 = values[key];
                            if ((value1 == value2) || (value1 instanceof Array && value2 instanceof Array &&
                                    $(value1).not(value2).length === 0 && $(value2).not(value1).length === 0) || ["action", "security", "sort", "sort_type", "limit"].indexOf(key) > -1) {
                                delete values[key];
                            }
                        }
                        values = estatebud_serialize_array_back(values);
                    }
                    return $.param(values);
                };

                var estatebud_fix_key = function (oldkey) {
                    var newkeys = {
                        bathrooms: "bathrooms_max",
                        bedrooms: "bedrooms_max",
                    }
                    if (newkeys.hasOwnProperty(oldkey)) return newkeys[oldkey];
                    return oldkey;
                };

                var estatebud_serialize_array_back = function (arr) {
                    var result = [];
                    for (var key in arr) {
                        var value = arr[key];
                        if (value.constructor === Array) {
                            for (var p = 0, len = value.length; p < len; p++)
                                result.push({
                                    name: key + "[]",
                                    value: value[p]
                                });
                        } else {
                            if (value !== "" && value !== 0 && value !== undefined) {
                                result.push({
                                    name: key,
                                    value: value
                                });
                            }
                        }
                    }
                    return result;
                };

                var estatebud_serialize_arrays = function (arr) {
                    var newArr = [];
                    for (var i in arr) {
                        var key = arr[i].name;
                        var value = arr[i].value;
                        if (key.substr(-2, 2) == "[]") {
                            key = key.replace(/\[\]/, '');
                            if (newArr[key] == undefined) newArr[key] = [];
                            newArr[key].push(value);
                        } else {
                            newArr[key] = value;
                        }
                    }
                    return newArr;
                };

                var estatebud_update_document_hash = function (queryString) {
                    if (rolling_back) return;
                    var pageUrl = '?' + queryString;
                    history.pushState('', '', pageUrl);
                };

                var estatebud_rollback_document = function (queryString) {
                    if (queryString.length > 0) {
                        container.find("form")[0].reset();
                        container.find("form").deserialize(queryString.substr(1));
                    } else {
                        container.find("form")[0].reset();
                    }
                    container.find("form select").trigger("change");
                };

                window.addEventListener("popstate", function () {
                    rolling_back = true;
                    estatebud_rollback_document(location.search);
                    estatebud_refresh_property_list();
                });

                container.find("select, input").on("change", function () {
                    if (!rolling_back) {
                        if ($(this).prop("name") != "offset") {
                            $("input[name='offset']").val(0);
                        }
                        estatebud_refresh_property_list();
                    }
                });

                estatebud_refresh_property_list();

                $(document).on("click", ".estatebud-pagelink", function () {
                    scroll_to_top = true;
                    var offset = $(this).data("offset");
                    $("input[name='offset']").val(offset).trigger("change");
                });
            }

        } else {

            var container_property = $("#estatebud-property-details");

            if (container_property.length > 0) {
                /**
                 * Share buttons
                 */

                jsSocials.setDefaults("email", {
                    logo: "icon-envelope-open"
                });

                jsSocials.setDefaults("facebook", {
                    logo: "icon-facebook-official"
                });

                jsSocials.setDefaults("googleplus", {
                    logo: "icon-gplus"
                });
                jsSocials.setDefaults("twitter", {
                    logo: "icon-twitter"
                });
                jsSocials.setDefaults("vkontakte", {
                    logo: "icon-vkontakte"
                });

                $(".estatebud-share-buttons").jsSocials({
                    shares: ["facebook", "twitter", "vkontakte", "googleplus", "email"],
                    url: location.href,
                    text: $(".estatebud-property-title").val(),
                    showLabel: false,
                    showCount: false,
                    shareIn: "popup"
                });

                /**
                 * Contact Form Submission
                 **/
                $(".estatebud-contact-form-submit").on("click", function () {
                    var that = $(this);
                    var form = that.parents("form").first().get(0);
                    if (form.checkValidity()) {
                        var button = $(form).find("[type='submit']");
                        var result = $(form).find(".contact-form-message");
                        button.prop("disabled", "disabled");
                        $.ajax({
                            method: "post",
                            dataType: "json",
                            url: estatebud.ajaxurl,
                            data: $(form).serialize(),
                            success: function (data) {
                                if (data.status == 'error') {
                                    result.removeClass("contact-form-success").addClass("contact-form-error").text(data.message);
                                } else if (data.status = 'success') {
                                    result.removeClass("contact-form-error").addClass("contact-form-success").text(data.message);
                                }
                                button.removeAttr("disabled");
                            },
                            error: function (xhr, status, error) {
                                result.removeClass("contact-form-success").addClass("contact-form-error").text(status);
                                button.removeAttr("disabled");
                            }
                        })
                    }
                });
            }
        }


        var fixSizes = function () {
            $(".estatebud-widget-container").each(function(){
                if($(this).innerWidth() < 500 ){
                    $(this).removeClass("estatebud-widget-container-vertical");
                }else{
                    $(this).addClass("estatebud-widget-container-vertical");
                }
                $(this).find(".estatebud-column").removeClass("estatebud-column-50");
                if($(this).find(".estatebud-column").first().width() < 250){
                    $(this).addClass("estatebud-widget-container-vertical");
                }
                if($(this).find(".estatebud-column").first().width() < 250){
                    $(this).find(".estatebud-column").addClass("estatebud-column-50");
                }
            });
        };

        var fixVideos = function () {
            $(".video-container iframe").each(function(){
                $(this).height($(this).width() * 9 / 16);
            });
        };

        $(window).on("resize", function(){
            fixSizes();
            fixVideos();
        });
        fixSizes();
        fixVideos();
    });
})(jQuery);