<?php

$currency = $estatebud_api->auth_info->currency;

function estatebud_get_translation_details($object)
{
    if (!$object) return "";
    $locale = str_replace("_", "-", get_locale());
    if($locale == 'el') {
        $locale = "el-GR";
    }
    if (property_exists($object, $locale))
        return $object->{$locale};
    else if (property_exists($object, explode("-", $locale)[0]))
        return $object->{explode("-", $locale)[0]};
    else if (property_exists($object, "en-US"))
        return $object->{"en-US"};
    else
        return "";
}

function estatebud_get_locations_details($object)
{
    $areas = [$object->area1_name, $object->area2_name, $object->area3_name];
    $areas = array_filter($areas);
    if (count($areas) > 1) {
        return implode(", ", array_slice($areas, -2, 2));
    } else if (count($areas)) {
        return $areas[0];
    } else {
        return "";
    }
}

function estatebud_remove_parenthesis($string){
    return preg_replace("/\s+\([^)]+\)/i", "", $string);
}

function estatebud_get_currency_details($data, $currency){
    $type = in_array($data->category, ["res_rent_long","res_rent_short","com_rent_long"]) ? "rent" : "price";
    $price = null;
    if($type=="rent"){
        if(property_exists($data,"rent")) $price = $data->rent;
    }else{
        if(property_exists($data, "price")) $price = $data->price;
    }
    $original = property_exists($data, "originalprice") ? $data->originalprice : null;
    if($price && property_exists($price, $currency)){
        $result = "<div style='line-height: 20px'>";
        $result .= estatebud_build_price($price->{$currency});
        if($original && property_exists($original,$currency)) {
            $result .= "<br><strike style='margin-right: 0'>".estatebud_build_price($original->{$currency})."</strike>";
        }
        $result .= "</div>";
        if($type == "rent"){
            $result .= "<span class='estatebud-property-rent-month'>&nbsp;/&nbsp;". __("month", "estatebud") . "</span>";
        }
        if(property_exists($price->{$currency}, "vat") && $price->{$currency}->vat == 1){
            $result .= "<small>" . __("+VAT", "estatebud") . "</small>";
        }
        echo $result;
    }else{
        echo __("On Request", "estatebud");
    }
}
function estatebud_build_price($value){
    $result = "";
    if(property_exists($value,"details")){
        if($value->details->dir == "left"){
            $result .= $value->details->symbol;
            if($value->details->space) $result .= " ";
        }
    }
    if(property_exists($value, "amount")){
        $result .= number_format($value->amount);
        if(property_exists($value,"details")){
            if($value->details->dir == "right"){
                if($value->details->space) $result .= " ";
                $result .= $value->details->symbol;
            }
        }
    }
    return $result;
}


function estatebud_get_distance_icon($key)
{
    switch ($key) {
        case "distancetoamenitieskm":
            return "<i class='icon-shopping-basket'></i>";
        case "distancetoairportkm":
            return "<i class='icon-flight'></i>";
        case "distancetoseakm":
            return "<i class='icon-sun'></i>";
        case "distancetoresortkm":
            return "<i class='icon-home'></i>";
        case "distancetoschoolskm":
            return "<i class='icon-graduation-cap'></i>";
        case "distancetotransitkm":
            return "<i class='icon-bus'></i>";
    }
    return "";
}

function estatebud_get_distance_km($km){
    if($km < 1) {
        return round($km * 1000)." m";
    }
     return $km." km";
}



?>
<div id="estatebud-property-details" class="estatebud-property-details-type-3">
    <div class="estatebud-row">
        <div class="estatebud-container">
            <div class='estatebud-block estatebud-block-half estatebud-block-left estatebud-header-container'>
                <div class="estatebud-property-price">
                    <?php echo estatebud_get_currency_details($details, $currency) ?>
                </div>
                <div class="estatebud-property-header">
                    <div class="estatebud-property-title">
                        <?php if(property_exists($details, "data") && property_exists($details->data, "bedrooms")) printf(_n("%d Bedroom", "%d Bedrooms", $details->data->bedrooms, "estatebud"), $details->data->bedrooms); ?> <?php echo estatebud_get_translation_details($details->type->translations); ?>
                    </div>
                    <div class="estatebud-property-location"><?php echo estatebud_get_locations_details($details); ?></div>
                </div>
            </div>
            <div class='estatebud-block estatebud-block-half estatebud-block-right'>
                <div class="estatebud-block estatebud-share">
                    <div class="estatebud-share-container">
                        <div class="estatebud-share-title"><?php _e("Share", "estatebud"); ?></div>
                        <div class="estatebud-share-buttons"></div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <?php if (property_exists($details, "images") && count($details->images) > 0) : ?>
    <div class="estatebud-row">
        <div class="estatebud-container">
            <div class="estatebud-slider">
                <div class="estatebud-slider-container">
                    <div id="estatebud-slider" class="estatebud-slider-3">
                    <?php foreach ((array)$details->images as $image) : ?>
                        <a data-fancybox="gallery" href="<?php echo $image->large; ?>"><img src="<?php echo $image->medium; ?>"></a>
                    <?php endforeach; ?>
                    </div>
                    <i class="fa fa-expand"></i>
                </div>
                <div class="estatebud-slider-nav">
                <?php foreach ((array)$details->images as $image2) : ?>
                    <img src="<?php echo $image2->thumb; ?>">
                <?php endforeach; ?>
                </div>
            </div>
        </div>
    </div>
    <script type="text/javascript">
        (function($){
            $("[data-fancybox]").fancybox({
                protect: true,
                loop : false,
                thumbs : {
                    axis : 'x',
                    autoStart: true,
                    hideOnClose: true
                },
                margin : [44,0,22,0]
            });
            $(".estatebud-slider-3").slick({
                swipe: false,
                arrows: false,
                dots: false,
                slidesToShow: 1,
                slidesToScroll: 1,
                asNavFor: ".estatebud-slider-nav",
                responsive: [
                    {
                        breakpoint: 768,
                        settings: {
                            arrows: true,
                            nextArrow: "<div class='estatebud-slick-next'><i class='fa fa-chevron-right'></i></div>",
                            prevArrow: "<div class='estatebud-slick-prev'><i class='fa fa-chevron-left'></i></div>",
                        }
                    }
                ]
            });
            $(".estatebud-slider-nav").slick({
                asNavFor: ".estatebud-slider-3",
                infinite: false,
                slidesToShow: 4,
                slidesToScroll: 1,
                arrows: false,
                dots: false,
                focusOnSelect: true,
                vertical: true,
                verticalSwiping: true
            });
        })(jQuery);
    </script>
    <?php endif; ?>
    <div class="estatebud-row estatebud-details">
        <div class="estatebud-container">
            <div class="estatebud-block estatebud-title estatebud-heading">
                <div class="estatebud-title-text" style='flex: 1'><?php echo __("Property Description", "estatebud"); ?></div>
                <div class="estatebud-id-text estatebud-align-right" style='flex: 1'><?php _e("#ID", "estatebud");?> <?php echo $property_id; ?></div>
            </div>
            <div class="estatebud-block">
                <div class="estatebud-property-infos">
                    <?php if(property_exists($details, "data") && property_exists($details->data,"bedrooms")):?><div class="estatebud-property-info"><i class="icon-bed"></i><b><?php echo __("Bedrooms", "estatebud"); ?>:</b> <?php echo $details->data->bedrooms; ?></div><?php endif; ?>
                    <?php if(property_exists($details, "data") && property_exists($details->data,"bathrooms")):?><div class="estatebud-property-info"><i class="icon-bath"></i><b><?php echo __("Bathrooms", "estatebud"); ?>:</b> <?php echo $details->data->bathrooms; ?></div><?php endif; ?>
                    <?php if(property_exists($details, "data") && property_exists($details->data,"toilets")):?><div class="estatebud-property-info"><i class="icon-droplet"></i><b><?php echo __("Toilets", "estatebud"); ?>:</b> <?php echo $details->data->toilets; ?></div><?php endif; ?>
                    <?php if($estatebud_api->auth_info->measurements == "imperial") :
                        if(property_exists($details, "data") && property_exists($details->data,"coveredft2")):?>
                        <div class="estatebud-property-info"><i class="icon-resize-full-alt"></i><b><?php echo __("Covered Area", "estatebud"); ?>:</b>
                        <?php echo $details->areas->coveredft2->value; ?></div>
                        <?php endif;
                        if(property_exists($details, "data") && property_exists($details->data,"plotft2")):?>
                        <div class="estatebud-property-info"><i class="icon-doc-landscape"></i><b><?php echo __("Plot Area", "estatebud"); ?>:</b>
                        <?php echo $details->areas->plotft2->value; ?></div><?php endif;
                        if(property_exists($details, "data") && property_exists($details->data,"coveredverandaft2")):?>
                        <div class="estatebud-property-info"><i class="icon-move"></i><b><?php echo __("Veranda", "estatebud"); ?>:</b>
                        <?php echo $details->areas->coveredverandaft2->value; ?></div><?php endif;
                    else:
                        if(property_exists($details, "data") && property_exists($details->data,"coveredm2")):?>
                        <div class="estatebud-property-info"><i class="icon-resize-full-alt"></i><b><?php echo __("Covered Area", "estatebud"); ?>:</b>
                        <?php echo $details->areas->coveredm2->value; ?></div>
                        <?php endif;
                        if(property_exists($details, "data") && property_exists($details->data,"plotm2")):?>
                        <div class="estatebud-property-info"><i class="icon-doc-landscape"></i><b><?php echo __("Plot Area", "estatebud"); ?>:</b>
                        <?php echo $details->areas->plotm2->value; ?></div>
                        <?php endif;
                        if(property_exists($details, "data") && property_exists($details->data,"coveredverandam2")):?>
                        <div class="estatebud-property-info"><i class="icon-move"></i><b><?php echo __("Veranda", "estatebud"); ?>:</b>
                        <?php echo $details->areas->coveredverandam2->value; ?></div>
                        <?php endif;
                    endif;?>
                </div>
                <?php if(property_exists($details, "description")) : ?>
                <div class="estatebud-description">
                    <?php echo nl2br(estatebud_get_translation_details($details->description)); ?>
                </div>
                <?php endif;?>
            </div>
            <div class="estatebud-container-row">
            <?php if (property_exists($details, "facilities") && count($details->facilities) > 0) : ?>
            <div>
                <div class="estatebud-block estatebud-title">
                    <div class="estatebud-title-text"><?php echo __("Facilities", "estatebud"); ?></div>
                </div>
                <div class="estatebud-block">
                    <ul class="estatebud-facilities" style="margin: 0">
                        <?php foreach ($details->facilities as $key => $facility) : ?>
                        <li class="estatebud-facility"><b><?php echo estatebud_get_translation_details($facility->translations); ?><?php echo $facility->value == "1" ? "</b>" : ":</b>" . $facility->value; ?></li>
                        <?php endforeach; ?>
                    </ul>
                </div>
            </div>
            <?php endif; ?>
            <?php if (property_exists($details, "features") && count($details->features) > 0) : ?>
            <div>
                <div class="estatebud-block estatebud-title">
                    <div class="estatebud-title-text"><?php echo __("Features", "estatebud"); ?></div>
                </div>
                <div class="estatebud-block">
                    <ul class="estatebud-features" style="margin: 0">
                        <?php foreach ($details->features as $key => $feature) : ?>
                        <li class="estatebud-feature"><b><?php echo estatebud_get_translation_details($feature->translations); ?></b></li>
                        <?php endforeach; ?>
                    </ul>
                </div>
            </div>
            <?php endif; ?>
            </div>
            <?php if (property_exists($details, "distances") && count($details->distances) > 0) : ?>
            <div class="estatebud-block estatebud-title">
                <div class="estatebud-title-text"><?php echo __("Distances", "estatebud"); ?></div>
            </div>
            <div class="estatebud-block">
                <div class="estatebud-distances">
                    <?php foreach ($details->distances as $key => $distance) : ?>
                    <div class="estatebud-distance"><?php echo estatebud_get_distance_icon($key); ?><b><?php echo estatebud_remove_parenthesis(estatebud_get_translation_details($distance->translations)); ?>: </b> <?php echo estatebud_get_distance_km(floatval($distance->value)); ?></div>
                    <?php endforeach; ?>
                </div>
            </div>
            <?php endif; ?>
            <?php if (property_exists($details, "floorplans") && count($details->floorplans) > 0) : ?>
            <div class="estatebud-block estatebud-title">
                <div class="estatebud-title-text"><?php echo __("Floor Plans", "estatebud"); ?></div>
            </div>
            <div class="estatebud-block">
                <div class="estatebud-floorplans">
                    <?php foreach ($details->floorplans as $key => $floorplan) : ?>
                    <a data-fancybox="gallery-2" class='estatebud-floorplan' href='<?php echo $floorplan->large;?>'>
                        <img src="<?php echo $floorplan->thumb;?>">
                    </a>
                    <?php endforeach; ?>
                </div>
                <script>
                    jQuery('.estatebud-floorplans').slick({
                        infinite: true,
                        slidesToShow: 3,
                        slidesToScroll: 1,
                        responsive: [
                            {
                                breakpoint: 1024,
                                settings: {
                                    slidesToShow: 3,
                                    slidesToScroll: 1,
                                    infinite: true
                                }
                            },
                            {
                                breakpoint: 600,
                                settings: {
                                    slidesToShow: 2,
                                    slidesToScroll: 1
                                }
                            },
                            {
                                breakpoint: 480,
                                settings: {
                                    slidesToShow: 1,
                                    slidesToScroll: 1
                                }
                            }
                        ]
                    });
                </script>
            </div>
            <?php endif; ?>
            <?php if (property_exists($details, "videos") && count($details->videos) > 0) : ?>
            <div class="estatebud-block estatebud-title">
                <div class="estatebud-title-text"><?php echo __("Videos", "estatebud"); ?></div>
            </div>
            <div class="estatebud-block">
                <div class="estatebud-videos">
                    <?php foreach ($details->videos as $key => $video) :
                        if($video->platform == 'youtube') :
                        ?>
                    <div class="estatebud-video video-container">
                        <iframe id="ytplayer" width=480 height=270 type="text/html" src="http://www.youtube.com/embed/<?php echo $video->platform_id;?>?autoplay=0&hl=<?php echo get_locale();?>&origin=<?php echo $_SERVER["HTTP_HOST"];?>" frameborder="0" allowfullscreen></iframe>
                    </div>
                    <?php endif; endforeach; ?>
                    <style>
                    .estatebud-videos {
                        display: flex;
                        flex-wrap: wrap;
                    }
                    .estatebud-video {
                        padding: 10px;
                        position: relative;
                    }
                    .video-container iframe {
                        width: 100%;
                    }
                    @media screen and (min-width: 768px){
                        .estatebud-video {
                            flex: 0 0 50%;
                        }
                    }
                    @media screen and (max-width: 768px){
                        .estatebud-video {
                            flex: 0 0 100%;
                            margin-bottom: 15px;
                        }
                    }
                    </style>
                </div>
            </div>
            <?php endif;?>

            <?php
$estatebud_gmaps_api_key = trim(get_option("estatebud_gmaps_api_key",""));
if($estatebud_gmaps_api_key != "") :

        $lat = trim($details->location_lat);
        $lng = trim($details->location_lng);
         if(property_exists($details,"location_lat") && property_exists($details,"location_lng") && !empty($lat) && !empty($lng)) : ?>
    <div class="estatebud-row estatebud-map" id="estatebud-map">
    </div>
    <?php endif; endif; ?>
            <div class="estatebud-block estatebud-title estatebud-heading">
                <div class="estatebud-title-text"><?php echo __("Contact", "estatebud"); ?></div>
            </div>
            <div class="estatebud-block estatebud-contact">
                <div class="estatebud-contact-text">
                    <?php echo __("Have any questions about the property?", "estatebud"); ?>
                    <span class="estatebud-contact-highlight"><?php echo __("We're ready to help!", "estatebud"); ?></span>
                </div>
                <div class="estatebud-contact-form">
                    <form method="post" onsubmit="return false;">
                        <div class='estatebud-form-container'>
                            <div class="estatebud-contact-left">
                                <input type="hidden" name="action" value="estatebud_send_contact">
                                <input type="hidden" name="property_id" value="<?php echo $property_id; ?>">
                                <input type="hidden" name="contact_security" value="<?php echo wp_create_nonce("estatebud_send_contact"); ?>">
                                <input type="text" required name="name" placeholder="<?php _e("Name", "estatebud"); ?>" />
                                <input type="email" required name="email" placeholder="<?php _e("E-mail", "estatebud"); ?>" />
                                <input type="text" required name="phone" placeholder="<?php _e("Phone", "estatebud"); ?>" />
                            </div>
                            <div class="estatebud-contact-right">
                                <textarea required name="message" placeholder="<?php _e("Message", "estatebud"); ?>"></textarea>

                            </div>
                        </div>
                        <?php
                            $privacy_policy = trim(get_option("estatebud_email_privacy_policy_url", ""));
                            if(!empty($privacy_policy)) : ?>
                            <div class="estatebud-contact-pp-url">
                                <input type='checkbox' class='styled_checkbox_small' id="estatebud_privacy_policy_check" name='estatebud-privacy-policy-accepted'>
                                <label for="estatebud_privacy_policy_check">
                                    <?php printf(__('I agree my details are processed in accordance with the <a href="%s" target="_blank">Privacy Policy</a>', "estatebud"), $privacy_policy);?>
                                </label>
                            </div>
                        <?php endif; ?>
                        <?php
                            $use_recaptcha = get_option("estatebud_use_recaptcha", false);
                            if($use_recaptcha) :
                                $site_key = get_option("recaptcha_sitekey_value", null); ?>
                                <div class="g-recaptcha" data-sitekey="<?php echo $site_key; ?>"></div>
                        <?php endif;?>
                        <button type="submit" class='estatebud-contact-form-submit'><?php _e("Send Message", "estatebud"); ?><i class='icon-hand-peace-o'></i></button>
                        <div class='contact-form-message'></div>
                    </form>
                </div>
            </div>
        </div>
    </div>

    <script type='text/javascript'>
    var estatebud_map;
    function estatebud_createMap() {
        <?php $lat = trim($details->location_lat);
        $lng = trim($details->location_lng);
        if(property_exists($details,"location_lat") && property_exists($details,"location_lng") && !empty($lat) && !empty($lng)) : ?>
        <?php echo "var lat = " . $details->location_lat . ", lng = " . $details->location_lng . ";"; ?>
        var mapProp= {
            center:new google.maps.LatLng(lat, lng),
            zoom:15,
        };
        var estatebud_map = new google.maps.Map(document.getElementById("estatebud-map"), mapProp);
        var marker = new google.maps.Marker({
            position: new google.maps.LatLng(lat, lng),
            map:estatebud_map
        });
        <?php endif;?>
    }
    </script>
</div>