<?php
$currency = $estatebud_api->auth_info->currency;

if(!function_exists("estatebud_get_translation")){
    function estatebud_get_translation($object){
        $locale = str_replace("_", "-", get_locale());

        if($locale == 'el') {
            $locale = "el-GR";
        }

        if(property_exists($object, $locale))
            return $object->{$locale};
        else
            return $object->{"en-US"};
    }
}

if(!function_exists("estatebud_get_locations")){
    function estatebud_get_locations($object){
        $areas = [$object->area1_name, $object->area2_name, $object->area3_name];
        $areas = array_filter($areas);
        if(count($areas) > 1) {
            return implode(", ", array_slice($areas,-2,2));
        } else if(count($areas)) {
            return $areas[0];
        } else { return ""; }
    }
}

if(!function_exists("estatebud_get_currency_details")){
    function estatebud_get_currency_details($data, $currency){
        $type = in_array($data->category, ["res_rent_long","res_rent_short","com_rent_long"]) ? "rent" : "price";
        $price = null;
        if($type=="rent"){
            if(property_exists($data,"rent")) $price = $data->rent;
        }else{
            if(property_exists($data, "price")) $price = $data->price;
        }
        $original = property_exists($data, "originalprice") ? $data->originalprice : null;
        if($price && property_exists($price, $currency)){
            $result = "<div style='line-height: 20px'>";
            $result .= estatebud_build_price($price->{$currency});
            if($original && property_exists($original,$currency)) {
                $result .= "<br><strike style='margin-right: 0'>".estatebud_build_price($original->{$currency})."</strike>";
            }
            $result .= "</div>";
            if($type == "rent"){
                $result .= "<span class='estatebud-property-rent-month'>&nbsp;/&nbsp;". __("month", "estatebud") . "</span>";
            }
            if(property_exists($price->{$currency}, "vat") && $price->{$currency}->vat == 1){
                $result .= "<small>" . __("+VAT", "estatebud") . "</small>";
            }
            echo $result;
        }else{
            echo __("On Request", "estatebud");
        }
    }

    function estatebud_build_price($value){
        $result = "";
        if(property_exists($value,"details")){
            if($value->details->dir == "left"){
                $result .= $value->details->symbol;
                if($value->details->space) $result .= " ";
            }
        }
        if(property_exists($value, "amount")){
            $result .= number_format($value->amount);
            if(property_exists($value,"details")){
                if($value->details->dir == "right"){
                    if($value->details->space) $result .= " ";
                    $result .= $value->details->symbol;
                }
            }
        }
        return $result;
    }
}

?>
<div class="estatebud-listing <?php echo get_option("estatebud_listing_type","");?>">
    <div class="estatebud-row">
    <?php
    if(isset($estatebud_list) && property_exists($estatebud_list, "query") && $estatebud_list->query->properties_total_count > 0 && property_exists($estatebud_list, "results")){
    $items_shown = 0;
    foreach($estatebud_list->results as $id => $data){?>
        <div class="estatebud-column">
            <?php $link = home_url( get_option("estatebud_property_page_id", null) ) . "/" . intval($id, 10);?>
            <a href="<?php echo $link;?>">
                <div class="estatebud-property">
                    <div class="estatebud-property-block-image">
                        <div class="estatebud-property-image">
                        <?php if(property_exists($data, "buyer")) : ?>
                            <div class="estatebud-property-sold"><?php _e("Sold", "estatebud");?></div>
                        <?php endif; ?>
                        <?php if(property_exists($data, "tenant")) : ?>
                            <div class="estatebud-property-rented"><?php _e("Rented", "estatebud");?></div>
                        <?php endif; ?>
                        <?php if(property_exists($data, "images") && count($data->images) > 0) : ?>
                            <img src='<?php echo $data->images[0]->thumb;?>'>
                        <?php else:
                            $placeholder = get_option("estatebud_placeholder_image", false);
                            if($placeholder === false){
                                $placeholder = plugin_dir_url(__FILE__) . "../assets/placeholder.png";
                                update_option("estatebud_placeholder_image", $placeholder);
                            }
                            echo "<img src='$placeholder'>";
                        endif; ?>
                        </div>
                    </div>
                    <div class='estatebud-property-block-info'>
                        <?php
                            /* Title Block */
                            $title = "";
                            if(property_exists($data, "data") && property_exists($data->data, "bedrooms")) {
                                $title .= sprintf(_n("%d Bedroom", "%d Bedrooms", $data->data->bedrooms, "estatebud"), $data->data->bedrooms) . " ";
                            }
                            if(property_exists($data,"type") && property_exists($data->type, "translations")){
                                $title .= estatebud_get_translation($data->type->translations);
                                $title = trim($title);
                                if($title != "") echo "<div class='estatebud-property-title'>$title</div>";
                            }
                        ?>
                        <?php
                            /* location block */
                            $location = estatebud_get_locations($data);
                            $location = trim($location);
                            echo "<div class='estatebud-property-location'>$location</div>";
                            ?>
                        <?php
                            /* tags block */
                            $tags = "";
                            if(property_exists($data, "titledeed") && $data->titledeed->value == "yes") $tags .= "<div class='estatebud-property-tag estatebud-property-tag-title-deed'>". __("Title Deed", "estatebud") . "</div>&nbsp;";
                            if(property_exists($data, "features")){
                                if(property_exists($data, "seafront") && $data->features->seafront->value == "1") $tags .= "<div class='estatebud-property-tag estatebud-property-tag-sea-front'>". __("Sea Front", "estatebud") . "</div>&nbsp;";
                                if(property_exists($data, "seaview") && $data->features->seaview->value == "1") $tags .= "<div class='estatebud-property-tag estatebud-property-tag-sea-view'>" . __("Sea View", "estatebud"). "</div>&nbsp;";
                            }
                            if(property_exists($data, "originalprice")) $tags .= "<div class='estatebud-property-tag estatebud-property-tag-reduced'>".__("Reduced", "estatebud")."</div>&nbsp;";
                            if(property_exists($data, "labels")){
                                foreach($data->labels as $label){
                                    if($label->public){
                                        $tags .= "<div class='estatebud-property-tag' style='background: #$label->color'>".__($label->name, "estatebud")."</div>&nbsp;";
                                    }
                                }
                            }
                            $tags = trim($tags);
                            if($tags != "") echo "<div class='estatebud-property-tags'>$tags</div>";
                        ?>
                        <div class="estatebud-property-price-info">
                            <?php echo estatebud_get_currency_details($data, $currency);?>
                        </div>
                        <div class="estatebud-property-footer">
                            <div class="estatebud-property-attrs">
                                <?php if(property_exists($data, "data") && property_exists($data->data, "bedrooms")) : ?>
                                <div class="estatebud-property-attr">
                                    <i class="icon-bed"></i>
                                    <?php echo intval($data->data->bedrooms) . "&nbsp;<span class='listing-visible'>" . __("Bedrooms", "estatebud") . "</span>";?>
                                </div>
                                <?php else: ?>
                                <div class="estatebud-property-attr">
                                <i class="icon-bed"></i>&nbsp;-&nbsp;
                                </div>
                                <?php endif; ?>
                                <?php if(property_exists($data, "data") && property_exists($data->data, "bathrooms")) : ?>
                                <div class="estatebud-property-attr">
                                    <i class="icon-bath"></i>
                                    <?php echo intval($data->data->bathrooms) . "&nbsp;<span class='listing-visible'>" . __("Bathrooms", "estatebud") . "</span>";?>
                                </div>
                                <?php else: ?>
                                <div class="estatebud-property-attr">
                                <i class="icon-bath"></i>&nbsp;-&nbsp;
                                </div>
                                <?php endif; ?>
                                <?php if(property_exists($data, "areas") && property_exists($data->areas, "coveredm2")) : ?>
                                <div class="estatebud-property-attr">
                                    <i class="icon-resize-full-alt"></i>
                                    <?php echo intval($data->areas->coveredm2->value) . "m²&nbsp;<span class='listing-visible'>" . __("Covered Area", "estatebud") . "</span>"; ?>
                                </div>
                                <?php else: ?>
                                <div class="estatebud-property-attr">
                                    <i class="icon-resize-full-alt"></i>&nbsp;-&nbsp;
                                </div>
                                <?php endif; ?>
                            </div>
                            <div class="estatebud-property-price estatebud-price-plus">
                                <i class="fa fa-plus"></i>
                            </div>
                        </div>
                    </div>
                </div>
            </a>
        </div>
    <?php
            $items_shown++;
            if(isset($is_widget) && $is_widget && $items_shown == $property_limit) break;
        }
    }else{
        echo '<div class="estatebud-column-full">';
        echo __("No properties found for this query. Please clear your filters or try a new query.", "estatebud");
        echo '</div>';
    } ?>
    <?php
    if(!isset($is_widget) || !$is_widget) require "estatebud-public-listing-pagination.php";?>
    </div>
</div>
<script type='text/javascript'>
    function estatebud_createMap(){
        // do nothing on listing page.
    }
</script>